import React from 'react';
import { Field, Select, useStyles2 } from '@grafana/ui';
import { css } from '@emotion/css';
import { GrafanaTheme2, SelectableValue } from '@grafana/data';

type TSProps = {
  label: string;
  description: string;
  value: number;
  onChange: (s: number) => void;
};

export const timeIntervals: Array<SelectableValue<number>> = [
  { label: '30s', value: 30 },
  { label: '1m', value: 60 },
  { label: '5m', value: 300 },
  { label: '30m', value: 1800 },
  { label: '1h', value: 3600 },
  { label: '12h', value: 43200 },
  { label: '1d', value: 86400 },
  { label: '1w', value: 604800 },
  { label: '1M', value: 2592000 },
];

export const TimeSelect = ({ label, description, value, onChange }: TSProps) => {
  const styles = useStyles2(getStyles);

  return (
    <div className={styles.select}>
      <Field label={label} description={description} required={true}>
        <Select
          options={timeIntervals}
          onChange={(v: SelectableValue<number>) => {
            onChange(v.value!);
          }}
          value={value}
          aria-label={`${label}-select`}
          menuShouldPortal
        />
      </Field>
    </div>
  );
};

const getStyles = (theme: GrafanaTheme2) => {
  return {
    select: css`
      margin-right: ${theme.spacing(1)};
    `,
  };
};
